Learn R Programming

rt.test (version 1.26.9)

Hodges-Lehmann-estimate: Hodges-Lehmann estimate

Description

Calculates the Hodges-Lehmann estimate.

Usage

HL.estimate(x, na.rm = FALSE, IncludeEqual = FALSE)

Arguments

x

a numeric vector of observations.

na.rm

a logical value indicating whether NA values should be stripped before the computation proceeds.

IncludeEqual

FALSE (default) calculates median of ([x[i]+x[j])/2) with i<j. TRUE calculates median of ([x[i]+x[j])/2) with i<=j.

Author

Chanseok Park and Min Wang

References

Hodges, J. L. and E. L. Lehmann (1963). Estimates of location based on rank tests. Annals of Mathematical Statistics, 34, 598--611.

See Also

mean for calculating sample mean and median for calculating sample median.

Examples

Run this code
x = c(0:10, 50)
HL.estimate(x)

Run the code above in your browser using DataLab