powered by
Calculates the Hodges-Lehmann estimate.
HL.estimate(x, na.rm = FALSE, IncludeEqual = FALSE)
a numeric vector of observations.
a logical value indicating whether NA values should be stripped before the computation proceeds.
FALSE (default) calculates median of ([x[i]+x[j])/2) with i<j. TRUE calculates median of ([x[i]+x[j])/2) with i<=j.
Chanseok Park and Min Wang
Hodges, J. L. and E. L. Lehmann (1963). Estimates of location based on rank tests. Annals of Mathematical Statistics, 34, 598--611.
mean for calculating sample mean and median for calculating sample median.
mean
median
x = c(0:10, 50) HL.estimate(x)
Run the code above in your browser using DataLab